==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/config/lang/de/lang.php <==
<?php
/**
 * German language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Andreas Gohr <andi@splitbrain.org>
 * @author Michael Klier <chi@chimeric.de>
 * @author Leo Moll <leo@yeasoft.com>
 * @author Florian Anderiasch <fa@art-core.org>
 * @author Robin Kluth <commi1993@gmail.com>
 * @author Arne Pelka <mail@arnepelka.de>
 */
$lang['menu']                  = 'Konfiguration';
$lang['error']                 = 'Die Einstellungen wurden wegen einer fehlerhaften Eingabe nicht gespeichert.
                           <br />Bitte überprüfen sie die rot umrandeten Eingaben und speichern Sie erneut.';
$lang['updated']               = 'Einstellungen erfolgreich gespeichert.';
$lang['nochoice']              = '(keine Auswahlmöglichkeiten vorhanden)';
$lang['locked']                = 'Die Konfigurationsdatei kann nicht geändert werden, wenn dies unbeabsichtigt ist
                           <br />überprüfen Sie, dass die Dateiberechtigungen korrekt gesetzt sind.';
$lang['_configuration_manager'] = 'Konfiguration';
$lang['_header_dokuwiki']      = 'DokuWiki-Konfiguration';
$lang['_header_plugin']        = 'Plugin-Konfiguration';
$lang['_header_template']      = 'Template-Konfiguration';
$lang['_header_undefined']     = 'Unbekannte Einstellungen';
$lang['_basic']                = 'Grund-Konfiguration';
$lang['_display']              = 'Anzeige-Konfiguration';
$lang['_authentication']       = 'Authentifizierungs-Konfiguration';
$lang['_anti_spam']            = 'Anti-Spam-Konfiguration';
$lang['_editing']              = 'Bearbeitungs-Konfiguration';
$lang['_links']                = 'Link-Konfiguration';
$lang['_media']                = 'Medien-Konfiguration';
$lang['_advanced']             = 'Erweiterte Konfiguration';
$lang['_network']              = 'Netzwerk-Konfiguration';
$lang['_plugin_sufix']         = 'Plugin Konfiguration';
$lang['_template_sufix']       = 'Template Konfiguration';
$lang['_msg_setting_undefined'] = 'Keine Konfigurationsmetadaten.';
$lang['_msg_setting_no_class'] = 'Keine Konfigurationsklasse.';
$lang['_msg_setting_no_default'] = 'Kein Standardwert.';
$lang['fmode']                 = 'Rechte für neue Dateien';
$lang['dmode']                 = 'Rechte für neue Verzeichnisse';
$lang['lang']                  = 'Sprache';
$lang['basedir']               = 'Installationsverzeichnis';
$lang['baseurl']               = 'Installationspfad (URL)';
$lang['savedir']               = 'Speicherverzeichnis';
$lang['start']                 = 'Startseitenname';
$lang['title']                 = 'Titel des Wikis';
$lang['template']              = 'Designvorlage (Template)';
$lang['license']               = 'Unter welcher Lizenz sollen Ihre Inhalte veröffentlicht werden?';
$lang['fullpath']              = 'Den kompletten Dateipfad im Footer anzeigen';
$lang['recent']                = 'Anzahl der Einträge in der Änderungsliste';
$lang['breadcrumbs']           = 'Anzahl der Einträge im "Krümelpfad"';
$lang['youarehere']            = 'Hierarchische Pfadnavigation verwenden';
$lang['typography']            = 'Typographische Ersetzungen';
$lang['htmlok']                = 'HTML erlauben';
$lang['phpok']                 = 'PHP erlauben';
$lang['dformat']               = 'Datumsformat (Siehe PHP <a href="http://www.php.net/strftime">strftime</a> Funktion)';
$lang['signature']             = 'Signatur';
$lang['toptoclevel']           = 'Inhaltsverzeichnis bei dieser Überschriftsgröße beginnen';
$lang['tocminheads']           = 'Mindestanzahl der Überschriften, die entscheidet ob ein Inhaltsverzeichnis erscheinen soll';
$lang['maxtoclevel']           = 'Maximale Überschriftsgröße für Inhaltsverzeichnis';
$lang['maxseclevel']           = 'Abschnitte bis zu dieser Stufe einzeln editierbar machen';
$lang['camelcase']             = 'CamelCase-Verlinkungen verwenden';
$lang['deaccent']              = 'Seitennamen bereinigen';
$lang['useheading']            = 'Erste Überschrift als Seitennamen verwenden';
$lang['refcheck']              = 'Auf Verwendung beim Löschen von Media-Dateien testen';
$lang['refshow']               = 'Wieviele Verwendungsorte der Media-Datei zeigen';
$lang['allowdebug']            = 'Debug-Ausgaben erlauben <b>Abschalten wenn nicht benötigt!</b>';
$lang['usewordblock']          = 'Spam-Blocking benutzen';
$lang['indexdelay']            = 'Zeit bevor Suchmaschinenindexierung erlaubt ist';
$lang['relnofollow']           = 'rel="nofollow" verwenden';
$lang['mailguard']             = 'E-Mail-Adressen schützen';
$lang['iexssprotect']          = 'Hochgeladene Dateien auf bösartigen JavaScript- und HTML-Code untersuchen.';
$lang['showuseras']            = 'Was angezeigt werden soll wenn der Benutzer, der zuletzt eine Seite bearbeitet hat angezeigt wird';
$lang['useacl']                = 'Zugangskontrolle verwenden';
$lang['autopasswd']            = 'Passwort automatisch generieren';
$lang['authtype']              = 'Authentifizierungsmechanismus';
$lang['passcrypt']             = 'Verschlüsselungsmechanismus';
$lang['defaultgroup']          = 'Standardgruppe';
$lang['superuser']             = 'Administrator - Eine Gruppe oder Nutzer mit vollem Zugriff auf alle Seiten und Administrationswerkzeuge.';
$lang['manager']               = 'Manager - Eine Gruppe oder Nutzer mit Zugriff auf einige Administrationswerkzeuge.';
$lang['profileconfirm']        = 'Profiländerung nur nach Passwortbestätigung';
$lang['disableactions']        = 'DokuWiki-Aktionen deaktivieren';
$lang['disableactions_check']  = 'Check';
$lang['disableactions_subscription'] = 'Seiten-Abonnements';
$lang['disableactions_nssubscription'] = 'Namensraum-Abonnements';
$lang['disableactions_wikicode'] = 'Quelltext betrachten/exportieren';
$lang['disableactions_other']  = 'Andere Aktionen (durch Komma getrennt)';
$lang['sneaky_index']          = 'Standardmäßig zeigt DokuWiki alle Namensräume in der Übersicht. Wenn diese Option aktiviert wird, werden alle Namensräume, für die der Benutzer keine Lese-Rechte hat, nicht angezeigt. Dies kann unter Umständen dazu führen, das lesbare Unter-Namensräume nicht angezeigt werden und macht die Übersicht evtl. unbrauchbar in Kombination mit bestimmten ACL Einstellungen.';
$lang['auth_security_timeout'] = 'Authentifikations-Timeout (Sekunden)';
$lang['securecookie']          = 'Sollen Cookies, die via HTTPS gesetzt wurden nur per HTTPS versendet werden? Deaktivieren Sie diese Option, wenn nur der Login Ihres Wikis mit SSL gesichert ist, aber das Betrachten des Wikis ungesichert geschieht.';
$lang['updatecheck']           = 'Automatisch auf Updates und Sicherheitswarnungen prüfen? DokuWiki muss sich dafür mit splitbrain.org verbinden.';
$lang['userewrite']            = 'URL rewriting';
$lang['useslash']              = 'Schrägstrich (/) als Namensraumtrenner in URLs verwenden';
$lang['usedraft']              = 'Während des Bearbeitens automatisch Zwischenentwürfe speichern';
$lang['sepchar']               = 'Worttrenner für Seitennamen in URLs';
$lang['canonical']             = 'Immer Links mit vollständigen URLs erzeugen';
$lang['autoplural']            = 'Bei Links automatisch nach vorhandenen Pluralformen suchen';
$lang['compression']           = 'Komprimierungsmethode für alte Seitenrevisionen';
$lang['cachetime']             = 'Maximale Cachespeicherung (Sek.)';
$lang['locktime']              = 'Maximales Alter für Seitensperren (Sek.)';
$lang['fetchsize']             = 'Maximale Größe (in Bytes), die fetch.php von extern herunterladen darf';
$lang['notify']                = 'Änderungsmitteilungen an diese E-Mail-Adresse versenden';
$lang['registernotify']        = 'Information über neu registrierte Nutzer an diese E-Mail-Adresse senden';
$lang['mailfrom']              = 'Absendermail für automatische Mails';
$lang['gzip_output']           = 'Seiten mit gzip komprimiert ausliefern';
$lang['gdlib']                 = 'GD Lib Version';
$lang['im_convert']            = 'Pfad zu ImageMagicks Konvertierwerkzeug';
$lang['jpg_quality']           = 'JPEG Kompressionsqualität (0-100)';
$lang['subscribers']           = 'E-Mail-Abos zulassen';
$lang['compress']              = 'JavaScript und Stylesheets komprimieren';
$lang['hidepages']             = 'Seiten verstecken (Regulärer Ausdruck)';
$lang['send404']               = 'Bei nicht vorhandenen Seiten mit 404 Fehlercode antworten';
$lang['sitemap']               = 'Google Sitemap erzeugen (Tage)';
$lang['broken_iua']            = 'Falls die Funktion ignore_user_abort auf Ihrem System nicht funktioniert, könnte der Such-Index nicht funktionieren. IIS+PHP/CGI ist bekannt dafür. Siehe auch <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a>.';
$lang['xsendfile']             = 'Den X-Sendfile header nutzen, um Dateien direkt vom Webserver ausliefern zu lassen? Ihr Webserver muss dies unterstützen!';
$lang['xmlrpc']                = 'XML-RPC Zugriff erlauben.';
$lang['renderer_xhtml']        = 'Standard-Renderer für die normale (XHTML) Wiki-Ausgabe.';
$lang['renderer__core']        = '%s (DokuWiki Kern)';
$lang['renderer__plugin']      = '%s (Plugin)';
$lang['rememberme']            = 'Permanente Login-Cookies erlauben (Auf diesem Computer eingeloggt bleiben)';
$lang['rss_type']              = 'XML-Feed Format';
$lang['rss_linkto']            = 'XML-Feed verlinken auf';
$lang['rss_content']           = 'Welche Inhalte sollen im XML-Feed dargestellt werden?';
$lang['rss_update']            = 'XML-Feed Aktualisierungsintervall (sec)';
$lang['recent_days']           = 'Wieviele letzte Änderungen sollen einsehbar bleiben? (Tage)';
$lang['rss_show_summary']      = 'Bearbeitungs-Zusammenfassung im XML Feed anzeigen';
$lang['target____wiki']        = 'Zielfenster für interne Links (target Attribut)';
$lang['target____interwiki']   = 'Zielfenster für InterWiki-Links (target Attribut)';
$lang['target____extern']      = 'Zielfenster für Externe Links (target Attribut)';
$lang['target____media']       = 'Zielfenster für (Bild-)Dateien (target Attribut)';
$lang['target____windows']     = 'Zielfenster für Windows Freigaben (target Attribut)';
$lang['proxy____host']         = 'Proxy-Server';
$lang['proxy____port']         = 'Proxy-Port';
$lang['proxy____user']         = 'Proxy Nutzername';
$lang['proxy____pass']         = 'Proxy Passwort';
$lang['proxy____ssl']          = 'SSL bei Verbindung zum Proxy verwenden';
$lang['safemodehack']          = 'Safemodehack verwenden';
$lang['ftp____host']           = 'FTP-Host für Safemodehack';
$lang['ftp____port']           = 'FTP-Port für Safemodehack';
$lang['ftp____user']           = 'FTP Nutzername für Safemodehack';
$lang['ftp____pass']           = 'FTP Passwort für Safemodehack';
$lang['ftp____root']           = 'FTP Wurzelverzeichnis für Safemodehack';
$lang['license_o_']            = 'Keine gewählt';
$lang['typography_o_0']        = 'keine';
$lang['typography_o_1']        = 'ohne einfache Anführungszeichen';
$lang['typography_o_2']        = 'mit einfachen Anführungszeichen (funktioniert nicht immer)';
$lang['userewrite_o_0']        = 'keines';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'DokuWiki';
$lang['deaccent_o_0']          = 'aus';
$lang['deaccent_o_1']          = 'Akzente und Umlaute umwandeln';
$lang['deaccent_o_2']          = 'Umschrift';
$lang['gdlib_o_0']             = 'GD Lib nicht verfügbar';
$lang['gdlib_o_1']             = 'Version 1.x';
$lang['gdlib_o_2']             = 'Automatisch finden';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'Abstrakt';
$lang['rss_content_o_diff']    = 'Unified Diff';
$lang['rss_content_o_htmldiff'] = 'HTML formatierte Diff Tabelle';
$lang['rss_content_o_html']    = 'Vollständiger HTML Inhalt';
$lang['rss_linkto_o_diff']     = 'Änderungen zeigen';
$lang['rss_linkto_o_page']     = 'geänderte Seite';
$lang['rss_linkto_o_rev']      = 'Liste aller Änderungen';
$lang['rss_linkto_o_current']  = 'Aktuelle Seite';
$lang['compression_o_0']       = 'keine';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'nicht benutzen';
$lang['xsendfile_o_1']         = 'Proprietärer lighttpd Header (vor Release 1.5)';
$lang['xsendfile_o_2']         = 'Standard X-Sendfile Header';
$lang['xsendfile_o_3']         = 'Proprietärer Nginx X-Accel-Redirect Header';
$lang['showuseras_o_loginname'] = 'Loginname';
$lang['showuseras_o_username'] = 'Vollständiger Name des Benutzers';
$lang['showuseras_o_email']    = 'E-Mail-Adresse des Benutzers (je nach Mailguard-Einstellung verschleiert)';
$lang['showuseras_o_email_link'] = 'E-Mail-Adresse des Benutzers als mailto:-Link';
$lang['useheading_o_0']        = 'Nie';
$lang['useheading_o_navigation'] = 'Nur Navigation';
$lang['useheading_o_content']  = 'Nur Wikiinhalt';
$lang['useheading_o_1']        = 'Immer';

==> dokuwiki_0.0.20110525a.orig.tar.gz: dokuwiki-2011-05-25a/lib/plugins/config/lang/de/lang.php <==
<?php
/**
 * German language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Andreas Gohr <andi@splitbrain.org>
 * @author Michael Klier <chi@chimeric.de>
 * @author Leo Moll <leo@yeasoft.com>
 * @author Florian Anderiasch <fa@art-core.org>
 * @author Robin Kluth <commi1993@gmail.com>
 * @author Arne Pelka <mail@arnepelka.de>
 * @author Dirk Einecke <dirk@dirkeinecke.de>
 * @author Blitzi94@gmx.de
 * @author Robert Bogenschneider <robog@GMX.de>
 * @author Robert Bogenschneider <robog@gmx.de>
 * @author Niels Lange <niels@boldencursief.nl>
 * @author Christian Wichmann <nospam@zone0.de>
 */
$lang['menu']                  = 'Konfiguration';
$lang['error']                 = 'Die Einstellungen wurden wegen einer fehlerhaften Eingabe nicht gespeichert.
<br />Bitte überprüfen sie die rot umrandeten Eingaben und speichern Sie erneut.';
$lang['updated']               = 'Einstellungen erfolgreich gespeichert.';
$lang['nochoice']              = '(keine Auswahlmöglichkeiten vorhanden)';
$lang['locked']                = 'Die Konfigurationsdatei kann nicht geändert werden, wenn dies unbeabsichtigt ist
 <br />überprüfen Sie, dass die Dateiberechtigungen korrekt gesetzt sind.';
$lang['danger']                = 'Vorsicht: Die Änderung dieser Option könnte Ihr Wiki und das Konfigurationsmenü unzugänglich machen.';
$lang['warning']               = 'Hinweis: Die Änderung dieser Option könnte unbeabsichtigtes Verhalten hervorrufen.';
$lang['security']              = 'Sicherheitswarnung: Die Änderung dieser Option könnte ein Sicherheitsrisiko darstellen.';
$lang['_configuration_manager'] = 'Konfiguration';
$lang['_header_dokuwiki']      = 'DokuWiki-Konfiguration';
$lang['_header_plugin']        = 'Plugin-Konfiguration';
$lang['_header_template']      = 'Template-Konfiguration';
$lang['_header_undefined']     = 'Unbekannte Einstellungen';
$lang['_basic']                = 'Grund-Konfiguration';
$lang['_display']              = 'Anzeige-Konfiguration';
$lang['_authentication']       = 'Authentifizierungs-Konfiguration';
$lang['_anti_spam']            = 'Anti-Spam-Konfiguration';
$lang['_editing']              = 'Bearbeitungs-Konfiguration';
$lang['_links']                = 'Link-Konfiguration';
$lang['_media']                = 'Medien-Konfiguration';
$lang['_advanced']             = 'Erweiterte Konfiguration';
$lang['_network']              = 'Netzwerk-Konfiguration';
$lang['_plugin_sufix']         = 'Plugin-Konfiguration';
$lang['_template_sufix']       = 'Template-Konfiguration';
$lang['_msg_setting_undefined'] = 'Keine Konfigurationsmetadaten.';
$lang['_msg_setting_no_class'] = 'Keine Konfigurationsklasse.';
$lang['_msg_setting_no_default'] = 'Kein Standardwert.';
$lang['fmode']                 = 'Rechte für neue Dateien';
$lang['dmode']                 = 'Rechte für neue Verzeichnisse';
$lang['lang']                  = 'Sprache';
$lang['basedir']               = 'Installationsverzeichnis';
$lang['baseurl']               = 'Installationspfad (URL)';
$lang['savedir']               = 'Speicherverzeichnis';
$lang['start']                 = 'Startseitenname';
$lang['title']                 = 'Titel des Wikis';
$lang['template']              = 'Designvorlage (Template)';
$lang['license']               = 'Unter welcher Lizenz sollen Ihre Inhalte veröffentlicht werden?';
$lang['fullpath']              = 'Den kompletten Dateipfad im Footer anzeigen';
$lang['recent']                = 'Anzahl der Einträge in der Änderungsliste';
$lang['breadcrumbs']           = 'Anzahl der Einträge im "Krümelpfad"';
$lang['youarehere']            = 'Hierarchische Pfadnavigation verwenden';
$lang['typography']            = 'Typographische Ersetzungen';
$lang['htmlok']                = 'HTML erlauben';
$lang['phpok']                 = 'PHP erlauben';
$lang['dformat']               = 'Datumsformat (Siehe PHP <a href="http://www.php.net/strftime">strftime</a> Funktion)';
$lang['signature']             = 'Signatur';
$lang['toptoclevel']           = 'Inhaltsverzeichnis bei dieser Überschriftsgröße beginnen';
$lang['tocminheads']           = 'Mindestanzahl der Überschriften die entscheidet, ob ein Inhaltsverzeichnis erscheinen soll';
$lang['maxtoclevel']           = 'Maximale Überschriftsgröße für Inhaltsverzeichnis';
$lang['maxseclevel']           = 'Abschnitte bis zu dieser Stufe einzeln editierbar machen';
$lang['camelcase']             = 'CamelCase-Verlinkungen verwenden';
$lang['deaccent']              = 'Seitennamen bereinigen';
$lang['useheading']            = 'Erste Überschrift als Seitennamen verwenden';
$lang['refcheck']              = 'Auf Verwendung beim Löschen von Media-Dateien testen';
$lang['refshow']               = 'Wieviele Verwendungsorte der Media-Datei zeigen';
$lang['allowdebug']            = 'Debug-Ausgaben erlauben <b>Abschalten wenn nicht benötigt!</b>';
$lang['usewordblock']          = 'Spam-Blocking benutzen';
$lang['indexdelay']            = 'Zeit bevor Suchmaschinenindexierung erlaubt ist';
$lang['relnofollow']           = 'rel="nofollow" verwenden';
$lang['mailguard']             = 'E-Mail-Adressen schützen';
$lang['iexssprotect']          = 'Hochgeladene Dateien auf bösartigen JavaScript- und HTML-Code untersuchen';
$lang['showuseras']            = 'Was angezeigt werden soll, wenn der Benutzer, der zuletzt eine Seite bearbeitet hat, angezeigt wird';
$lang['useacl']                = 'Zugangskontrolle verwenden';
$lang['autopasswd']            = 'Passwort automatisch generieren';
$lang['authtype']              = 'Authentifizierungsmechanismus';
$lang['passcrypt']             = 'Verschlüsselungsmechanismus';
$lang['defaultgroup']          = 'Standardgruppe';
$lang['superuser']             = 'Administrator - Eine Gruppe oder Nutzer mit vollem Zugriff auf alle Seiten und Administrationswerkzeuge.';
$lang['manager']               = 'Manager - Eine Gruppe oder Nutzer mit Zugriff auf einige Administrationswerkzeuge.';
$lang['profileconfirm']        = 'Profiländerung nur nach Passwortbestätigung';
$lang['disableactions']        = 'DokuWiki-Aktionen deaktivieren';
$lang['disableactions_check']  = 'Check';
$lang['disableactions_subscription'] = 'Seiten-Abonnements';
$lang['disableactions_wikicode'] = 'Quelltext betrachten/exportieren';
$lang['disableactions_other']  = 'Andere Aktionen (durch Komma getrennt)';
$lang['sneaky_index']          = 'Standardmäßig zeigt DokuWiki alle Namensräume in der Übersicht. Wenn diese Option aktiviert wird, werden alle Namensräume, für die der Benutzer keine Lese-Rechte hat, nicht angezeigt. Dies kann unter Umständen dazu führen, das lesbare Unter-Namensräume nicht angezeigt werden und macht die Übersicht evtl. unbrauchbar in Kombination mit bestimmten ACL Einstellungen.';
$lang['auth_security_timeout'] = 'Authentifikations-Timeout (Sekunden)';
$lang['securecookie']          = 'Sollen Cookies, die via HTTPS gesetzt wurden nur per HTTPS versendet werden? Deaktivieren Sie diese Option, wenn nur der Login Ihres Wikis mit SSL gesichert ist, aber das Betrachten des Wikis ungesichert geschieht.';
$lang['xmlrpc']                = 'XML-RPC-Zugriff erlauben.';
$lang['xmlrpcuser']            = 'XML-RPC-Zugriff auf folgende Gruppen oder Benutzer (kommasepariert) beschränken. Wenn Sie dieses Feld leer lassen, wir der Zugriff jedem gewährt.';
$lang['updatecheck']           = 'Automatisch auf Updates und Sicherheitswarnungen prüfen? DokuWiki muss sich dafür mit update.dokuwiki.org verbinden.';
$lang['userewrite']            = 'URL rewriting';
$lang['useslash']              = 'Schrägstrich (/) als Namensraumtrenner in URLs verwenden';
$lang['usedraft']              = 'Während des Bearbeitens automatisch Zwischenentwürfe speichern';
$lang['sepchar']               = 'Worttrenner für Seitennamen in URLs';
$lang['canonical']             = 'Immer Links mit vollständigen URLs erzeugen';
$lang['fnencode']              = 'Methode um nicht-ASCII Dateinamen zu kodieren.';
$lang['autoplural']            = 'Bei Links automatisch nach vorhandenen Pluralformen suchen';
$lang['compression']           = 'Komprimierungsmethode für alte Seitenrevisionen';
$lang['cachetime']             = 'Maximale Cachespeicherung (Sekunden)';
$lang['locktime']              = 'Maximales Alter für Seitensperren (Sekunden)';
$lang['fetchsize']             = 'Maximale Größe (in Bytes), die fetch.php von extern herunterladen darf';
$lang['notify']                = 'Änderungsmitteilungen an diese E-Mail-Adresse versenden';
$lang['registernotify']        = 'Information über neu registrierte Nutzer an diese E-Mail-Adresse senden';
$lang['mailfrom']              = 'Absender-E-Mail-Adresse für automatische Mails';
$lang['mailprefix']            = 'Präfix für E-Mail-Betreff beim automatischen Versand von Benachrichtigungen';
$lang['gzip_output']           = 'Seiten mit gzip komprimiert ausliefern';
$lang['gdlib']                 = 'GD Lib Version';
$lang['im_convert']            = 'Pfad zu ImageMagicks Konvertierwerkzeug';
$lang['jpg_quality']           = 'JPEG Kompressionsqualität (0-100)';
$lang['subscribers']           = 'E-Mail-Abos zulassen';
$lang['subscribe_time']        = 'Zeit nach der Zusammenfassungs- und Änderungslisten-E-Mails verschickt werden; Dieser Wert sollte kleiner als die in recent_days konfigurierte Zeit sein.';
$lang['compress']              = 'JavaScript und Stylesheets komprimieren';
$lang['hidepages']             = 'Seiten verstecken (Regulärer Ausdruck)';
$lang['send404']               = 'Bei nicht vorhandenen Seiten mit 404 Fehlercode antworten';
$lang['sitemap']               = 'Google Sitemap erzeugen (Tage)';
$lang['broken_iua']            = 'Falls die Funktion ignore_user_abort auf Ihrem System nicht funktioniert, könnte der Such-Index nicht funktionieren. IIS+PHP/CGI ist bekannt dafür. Siehe auch <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a>.';
$lang['xsendfile']             = 'Den X-Sendfile-Header nutzen, um Dateien direkt vom Webserver ausliefern zu lassen? Ihr Webserver muss dies unterstützen!';
$lang['renderer_xhtml']        = 'Standard-Renderer für die normale (XHTML) Wiki-Ausgabe.';
$lang['renderer__core']        = '%s (DokuWiki Kern)';
$lang['renderer__plugin']      = '%s (Plugin)';
$lang['rememberme']            = 'Permanente Login-Cookies erlauben (Auf diesem Computer eingeloggt bleiben)';
$lang['rss_type']              = 'XML-Feed-Format';
$lang['rss_linkto']            = 'XML-Feed verlinken auf';
$lang['rss_content']           = 'Welche Inhalte sollen im XML-Feed dargestellt werden?';
$lang['rss_update']            = 'XML-Feed Aktualisierungsintervall (Sekunden)';
$lang['recent_days']           = 'Wieviele letzte Änderungen sollen einsehbar bleiben? (Tage)';
$lang['rss_show_summary']      = 'Bearbeitungs-Zusammenfassung im XML-Feed anzeigen';
$lang['target____wiki']        = 'Zielfenster für interne Links (target Attribut)';
$lang['target____interwiki']   = 'Zielfenster für InterWiki-Links (target Attribut)';
$lang['target____extern']      = 'Zielfenster für Externe Links (target Attribut)';
$lang['target____media']       = 'Zielfenster für (Bild-)Dateien (target Attribut)';
$lang['target____windows']     = 'Zielfenster für Windows Freigaben (target Attribut)';
$lang['proxy____host']         = 'Proxy-Server';
$lang['proxy____port']         = 'Proxy-Port';
$lang['proxy____user']         = 'Proxy Nutzername';
$lang['proxy____pass']         = 'Proxy Passwort';
$lang['proxy____ssl']          = 'SSL bei Verbindung zum Proxy verwenden';
$lang['proxy____except']       = 'Regulärer Ausdruck um Adressen zu beschreiben, für die kein Proxy verwendet werden soll';
$lang['safemodehack']          = 'Safemodehack verwenden';
$lang['ftp____host']           = 'FTP-Host für Safemodehack';
$lang['ftp____port']           = 'FTP-Port für Safemodehack';
$lang['ftp____user']           = 'FTP Nutzername für Safemodehack';
$lang['ftp____pass']           = 'FTP Passwort für Safemodehack';
$lang['ftp____root']           = 'FTP Wurzelverzeichnis für Safemodehack';
$lang['license_o_']            = 'Keine gewählt';
$lang['typography_o_0']        = 'keine';
$lang['typography_o_1']        = 'ohne einfache Anführungszeichen';
$lang['typography_o_2']        = 'mit einfachen Anführungszeichen (funktioniert nicht immer)';
$lang['userewrite_o_0']        = 'keines';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'DokuWiki';
$lang['deaccent_o_0']          = 'aus';
$lang['deaccent_o_1']          = 'Akzente und Umlaute umwandeln';
$lang['deaccent_o_2']          = 'Umschrift';
$lang['gdlib_o_0']             = 'GD Lib nicht verfügbar';
$lang['gdlib_o_1']             = 'Version 1.x';
$lang['gdlib_o_2']             = 'Automatisch finden';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'Abstrakt';
$lang['rss_content_o_diff']    = 'Unified Diff';
$lang['rss_content_o_htmldiff'] = 'HTML formatierte Diff-Tabelle';
$lang['rss_content_o_html']    = 'Vollständiger HTML-Inhalt';
$lang['rss_linkto_o_diff']     = 'Änderungen zeigen';
$lang['rss_linkto_o_page']     = 'geänderte Seite';
$lang['rss_linkto_o_rev']      = 'Liste aller Änderungen';
$lang['rss_linkto_o_current']  = 'Aktuelle Seite';
$lang['compression_o_0']       = 'keine';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'nicht benutzen';
$lang['xsendfile_o_1']         = 'Proprietärer lighttpd-Header (vor Release 1.5)';
$lang['xsendfile_o_2']         = 'Standard X-Sendfile-Header';
$lang['xsendfile_o_3']         = 'Proprietärer Nginx X-Accel-Redirect-Header';
$lang['showuseras_o_loginname'] = 'Loginname';
$lang['showuseras_o_username'] = 'Vollständiger Name des Benutzers';
$lang['showuseras_o_email']    = 'E-Mail-Adresse des Benutzers (je nach Mailguard-Einstellung verschleiert)';
$lang['showuseras_o_email_link'] = 'E-Mail-Adresse des Benutzers als mailto:-Link';
$lang['useheading_o_0']        = 'Nie';
$lang['useheading_o_navigation'] = 'Nur Navigation';
$lang['useheading_o_content']  = 'Nur Wikiinhalt';
$lang['useheading_o_1']        = 'Immer';
$lang['readdircache']          = 'Maximales Alter des readdir-Caches (Sekunden)';
